import React, { useState, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { animate, csv, scaleLinear, scaleBand, max } from 'd3';

const csvUrl = 'https://gist.githubusercontent.com/performautodev/ab00b6300b1a235cde9c57600992b86d/raw/9c2f36181b2f090e91dac0b072405b6fe033e60d/UN_Population_2019.csv';
const width = 960;
const height = 500;
const margin = { top: 30, bottom: 65, left: 220, right: 40 };

const App = () => {
	const [data, setData] = useState(null);
  useEffect(() => {
    const row = d => {
      d.Population = +d['2020'];
      return d;
    }
  	csv(csvUrl, row).then(data => {
      setData(data.slice(0,10));
    });
  }, []);
  
  if (!data) {
    return <pre>Loading...</pre>;
  }
  
  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
  
  const xScale = scaleLinear().domain([0,max(data, d => d.Population)]).range([0,innerWidth]);
  const yScale = scaleBand().domain(data.map(d => d.Country)).range([0, innerHeight]).paddingInner(0.15);
  
  console.log("Error!");
  
  return (
  	<svg width={width} height={height}>
      <g transform={`translate(${margin.left}, ${margin.top})`}>
        {xScale.ticks().map(tickValue => 
                           <g className="tick" key={tickValue} transform={`translate(${xScale(tickValue)},0)`}>
                            <line 
                             y2={innerHeight}
                             stroke='black'
                             />
                              <text 
                                y={innerHeight+3}
                                style={{textAnchor:'middle'}}
                                dy="0.71em"
                                >{tickValue}</text>
                            </g>
                           )}
        {yScale.domain().map(tickValue => 
                             <g className="tick" key={tickValue}>
                            <text
                              y={yScale(tickValue) + yScale.bandwidth()/2}
                              style={{textAnchor: 'end'}}
                              x={-3}
                              dy="0.32em"
                              >{tickValue}</text>
                               </g>
                            )}
        { data.map(d => <g> 
                   <rect x={0}
                          key={d.Country}
                          className='bars'
                        y={yScale(d.Country)}
                        width={xScale(d.Population)}
                        height={yScale.bandwidth()}
                     >
                     <animate attributeName="width" from="0" to={xScale(d.Population)} dur="1s"/>
                     </rect></g>
                )
      }
      </g>
    </svg>
  );
}

ReactDOM.render(<App />, document.getElementById('root'));
